/*
 * Copyright (c) 1997 Vectaport Inc.
 *
 * Permission to use, copy, modify, distribute, and sell this software and
 * its documentation for any purpose is hereby granted without fee, provided
 * that the above copyright notice appear in all copies and that both that
 * copyright notice and this permission notice appear in supporting
 * documentation, and that the names of the copyright holders not be used in
 * advertising or publicity pertaining to distribution of the software
 * without specific, written prior permission.  The copyright holders make
 * no representations about the suitability of this software for any purpose.
 * It is provided "as is" without express or implied warranty.
 *
 * THE COPYRIGHT HOLDERS DISCLAIM ALL WARRANTIES WITH REGARD TO THIS
 * SOFTWARE, INCLUDING ALL IMPLIED WARRANTIES OF MERCHANTABILITY AND FITNESS.
 * IN NO EVENT SHALL THE COPYRIGHT HOLDERS BE LIABLE FOR ANY SPECIAL,
 * INDIRECT OR CONSEQUENTIAL DAMAGES OR ANY DAMAGES WHATSOEVER RESULTING
 * FROM LOSS OF USE, DATA OR PROFITS, WHETHER IN AN ACTION OF CONTRACT,
 * NEGLIGENCE OR OTHER TORTIOUS ACTION, ARISING OUT OF OR IN CONNECTION
 * WITH THE USE OR PERFORMANCE OF THIS SOFTWARE.
 *
 */

#ifndef losfunc_h
#define losfunc_h

#include <ComTerp/comfunc.h>
#include <OverlayUnidraw/clippoly.h>

class ComTerp;

class DemLosFunc : public ComFunc {
public:
    DemLosFunc(ComTerp*);
    virtual void execute();
    virtual const char* docstring() { 
      return "fclass=%s(\
\tlostype /* 0=viewshed, 1=profile */\
\tvaltype /* 0 = 2val, 1 = 4val */\
\trange\
\ttargwidth\
\ttargheight\
\tobsheight\
\tobsx\
\tobsy\
\tendazimuth\
\tstartazimuth\
\tdtedpath\
) -- compute DEM viewshed and return as feature class";
    }
};

class LosVisUtmFunc : public ComFunc {
public:
  LosVisUtmFunc(ComTerp*);
  virtual void execute();
    virtual const char* docstring() { 
      return "i=%s(losfc utmx utmy) -- get visibility index at utmx,utmy"; }
};

class DemElevGeoFunc : public ComFunc {
public:
    DemElevGeoFunc(ComTerp*);
    virtual void execute();
    virtual const char* docstring() { 
      return "dbl=%s(lat lon) -- get elevation at lat,lon"; }
};

class DemElevUtmFunc : public ComFunc {
public:
    DemElevUtmFunc(ComTerp*);
    virtual void execute();
    virtual const char* docstring() { 
      return "dbl=%s(px py) -- get elevation at utmx,utmy"; }
};


class DemTriUtmFunc : public ComFunc {
public:
    DemTriUtmFunc(ComTerp*);
    virtual void execute();
    virtual const char* docstring() { 
      return "fc=%s(dempath utmx utmy) -- get elevation triangle at utmx,utmy"; }
};

class DemGridUtmFunc : public ComFunc {
public:
    DemGridUtmFunc(ComTerp*);
    virtual void execute();
    virtual const char* docstring() { 
      return "fc=%s(dempath utmx0 utmy0 utmx1 utmy1) -- get elevation grid between coordinates"; }
};

class DemXYZFunc : public ComFunc {
public:
    DemXYZFunc(ComTerp*);
    virtual void execute();
    virtual const char* docstring() { 
      return "fclass=%s(dem_path1 [... dted_pathN] :basename prfxstr :sw_e utmE :sw_n utmN :tsize tilesize :samplerate meters)"; }
protected:
  int _basename_symid;
  int _swe_symid;
  int _swn_symid;
  int _tsize_symid;
  int _samplerate_symid;
  int _zone_symid;
};

#endif
